@@ -1,11 +1,12 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
 # did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
+## nofilter(TidyAll::Plugin::Znuny::Perl::DBObject)
 
 package Kernel::Modules::AdminCustomerUser;
 
@@ -1040,8 +1041,8 @@ sub _Overview {
 sub _Edit {
     my ( $Self, %Param ) = @_;
 
-    # Get layout object.
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $LayoutObject    = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $HTMLUtilsObject = $Kernel::OM->Get('Kernel::System::HTMLUtils');
 
     my $Output = '';
 
@@ -1080,20 +1081,32 @@ sub _Edit {
     # Get config object
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
+    my $Backend = $ConfigObject->Get( $Param{Source} );
+
     # update user
-    if ( $ConfigObject->Get( $Param{Source} )->{ReadOnly} || $ConfigObject->Get( $Param{Source} )->{Module} =~ /LDAP/i )
-    {
+    if ( $Backend->{ReadOnly} || $Backend->{Module} =~ /LDAP/i ) {
         $UpdateOnlyPreferences = 1;
     }
 
     # Get dynamic field backend object.
     my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
     my $ParamObject               = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $DBObject                  = $Kernel::OM->Get('Kernel::System::DB');
+
+    my %ColumnMaxLength;
+    if ( $Backend->{Params}->{Table} && $Backend->{Module} =~ /DB/i ) {
+
+        %ColumnMaxLength = $DBObject->GetColumnMaxLengths(
+            Table => $Backend->{Params}->{Table},
+        );
+    }
 
     ENTRY:
-    for my $Entry ( @{ $ConfigObject->Get( $Param{Source} )->{Map} } ) {
+    for my $Entry ( @{ $Backend->{Map} } ) {
         next ENTRY if !$Entry->[0];
 
+        $Param{MaxLength} = $ColumnMaxLength{ lc( $Entry->[2] ) } || undef;
+
         # Handle dynamic fields
         if ( $Entry->[5] eq 'dynamic_field' ) {
 
@@ -1245,9 +1258,24 @@ sub _Edit {
             my $UseAutoComplete = $Kernel::OM->Get('Kernel::Config')->Get('AdminCustomerUser::UseAutoComplete');
 
             if ($UseAutoComplete) {
+                my $Value = $Param{ $Entry->[0] } || $Param{CustomerID} || '';
 
-                my $Value = $Param{ $Entry->[0] } || $Param{CustomerID};
-                $Param{Option} = '<input type="text" id="UserCustomerID" name="UserCustomerID" value="' . $Value . '"
+                my %SafeValue = $HTMLUtilsObject->Safety(
+                    String       => $Value,
+                    NoApplet     => 1,
+                    NoObject     => 1,
+                    NoEmbed      => 1,
+                    NoSVG        => 1,
+                    NoImg        => 1,
+                    NoIntSrcLoad => 0,
+                    NoExtSrcLoad => 1,
+                    NoJavaScript => 1,
+                );
+
+                my $SafeValue = $HTMLUtilsObject->ToHTML( String => $SafeValue{String} // '' );
+
+                $Param{Option}
+                    = '<input type="text" id="UserCustomerID" name="UserCustomerID" value="' . $SafeValue . '"
                     class="W50pc CustomerAutoCompleteSimple '
                     . $Param{RequiredClass} . ' '
                     . $Param{Errors}->{ $Entry->[0] . 'Invalid' }
