@@ -46,12 +46,11 @@ sub Run {
         Type => 'XMLParse',
     );
 
-    # Note: Znuny and Znuny4OTRS in case one of the packages later will be built with the Znuny prefix
     my @PackageNames = (
-        'Znuny-NoteToLinkedTicket',
-        'Znuny4OTRS-NoteToLinkedTicket',
-        'Znuny4OTRS-UserMaxArticlesPerPage',
-        'Znuny-DynamicFieldWebserviceTicketIDPayload',
+        'Znuny-MarkTicketSeenUnseen',
+        'Znuny4OTRS-MarkTicketSeenUnseen',
+        'Znuny-CustomPriorityColor',
+        'Znuny4OTRS-CustomPriorityColor',
     );
 
     PACKAGENAME:
